@@ -1,5 +1,5 @@
 package DBIx::Class::Helper::ResultSet::Explain;
-$DBIx::Class::Helper::ResultSet::Explain::VERSION = '2.023005';
+$DBIx::Class::Helper::ResultSet::Explain::VERSION = '2.023006';
 use strict;
 use warnings;
 
@@ -257,12 +257,28 @@ to your entire schema.
      "Seq Scan on \"Gnarly\" me  (cost=0.00..16.20 rows=620 width=100) (actual time=0.001..0.001 rows=0 loops=1)"
    ],
    [
-     "Total runtime: 0.021 ms"
+     "Total runtime: 0.017 ms"
    ]
  ]
 
 =head2 mysql
 
+ [
+   [
+     1,
+     "SIMPLE",
+     "me",
+     "ALL",
+     undef,
+     undef,
+     undef,
+     undef,
+     1,
+     "100.00",
+     ""
+   ]
+ ]
+
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
