@@ -1,6 +1,6 @@
 package ParentSchema::Result::Bar;
 
-use DBIx::Class::Candy;
+use DBIx::Class::Candy -base => 'ParentSchema::Result';
 
 table 'Bar';
 
@@ -10,12 +10,13 @@ column id => {
 };
 
 column foo_id => {
+   data_type => 'integer',
    keep_storage_value => 1,
 };
 
 primary_key 'id';
 
-belongs_to foo => 'ParentSchema::Result::Foo', 'foo_id';
-has_many  foos => 'ParentSchema::Result::Foo', 'bar_id';
+belongs_to foo => '::Foo', 'foo_id';
+has_many  foos => '::Foo', 'bar_id';
 
 1;
